==> apracjs-13.1.29.tgz: package/aprac/UI/Print/ClientSelector.js <==
Type.registerNamespace('ApracJs.UI.Print');

ApracJs.UI.Print.ClientSelectorAction = function() {
  ApracJs.UI.Print.ClientSelectorAction.initializeBase(this);
};

ApracJs.UI.Print.ClientSelectorAction.prototype = {
  initialize: function() {
    ApracJs.UI.Print.ClientSelectorAction.callBaseMethod(this, 'initialize');

    if ($settings.HideAccessCode) {
      this.get_form().accessFlex.set_visible(false);
    }

    this.loadClients();
    this.selectMap = new Map();
  },

  dispose: function() {
    ApracJs.UI.Print.ClientSelectorAction.callBaseMethod(this, 'dispose');
  },

  loadClients: function() {
    var that = this;
    $print.getPrintClients(function(data) {
      if (!data) data = [];
      if (data.length == 0) {
        $common.showInfo('ûȨԶ̴ӡԶ̴ӡû޷ʵ<p>ȻȡȨ룬ȻȨ뷢͸װTeemo汾ӡȨ</p>');
      }
      var form = that.get_form();
      form.listClient.set_items(data);
      form.listClient.set_selectedIndex(0);
      that.doClientChanged(form.listClient);
    });
  },

  doClientChanged: function(sender) {
    var index = sender.get_selectedIndex();
    var items = sender.get_items();
    var grid = this.get_form().gridPrint;
    if (items.length === 0) {
      grid.refresh(null);
      return;
    }

    var selectClient = items[index];
    var printerNames = [];
    for (var i = 0; i < selectClient.printerNames.length; i++) {
      printerNames.push({
        PrinterName: selectClient.printerNames[i].printerName
      });
    }
    grid.dataBind(printerNames);
  },

  doSelect: function(sender) {
    var form = sender.get_form();
    var printer = form.gridPrint.get_selectedRowData();
    if (!printer) return;
    var clientToken = form.listClient.get_value();
    var clientTagName = form.listClient.get_text();
    var printerName = printer.PrinterName;
    var text = clientTagName + "(" + printerName + ")";
    var item = {
      text: text,
      clientToken: clientToken,
      printerName: printerName
    };
    this.selectMap.set(item.clientToken, item);
    this.refreshItems();
  },

  refreshItems: function() {
    var btnsSelect = this.get_form().btnsSelect;
    var items = [];
    this.selectMap.forEach(function(value) {
      items.push(value);
    });
    btnsSelect.set_items(items);
  },

  doRefresh: function(sender) {
    var grid = this.get_form().gridPrint;
    grid.dataBind([]);
    this.loadClients();
    this.selectMap.clear();
    this.refreshItems();
  },

  doGetAccessCode: function(sender) {
    $print.getAccessCode(function(result) {
      if (!result) {
        $common.showTips('Ȩȡ쳣');
        return;
      }
      sender.get_form().teAccessCode.set_text(result.accessCode);
    });
  },

  doRemove: function(sender, args) {
    var clientToken = args.get_data().clientToken;
    this.selectMap.delete(clientToken);
    this.refreshItems();
  },

  doSure: function(sender) {
    if (this.selectMap.size === 0) {
      $common.showTips('ָӡͻ');
      return;
    }
    var items = [];
    this.selectMap.forEach(function(value) {
      items.push(value);
    });
    var form = sender.get_form();
    form.result = items;
    form.doOk();
  }
};
ApracJs.UI.Print.ClientSelectorAction.registerClass('ApracJs.UI.Print.ClientSelectorAction', Sys.UI.PageAction);

==> apracjs-15.1.6.tgz: package/aprac/UI/Print/ClientSelector.js <==
﻿Type.registerNamespace('ApracJs.UI.Print');

ApracJs.UI.Print.ClientSelectorAction = function() {
  ApracJs.UI.Print.ClientSelectorAction.initializeBase(this);
};

ApracJs.UI.Print.ClientSelectorAction.prototype = {
  initialize: function() {
    ApracJs.UI.Print.ClientSelectorAction.callBaseMethod(this, 'initialize');

    if ($settings.HideAccessCode) {
      this.get_form().accessFlex.set_visible(false);
      this.get_form().accessPanel.set_visible(false);
    }

    this.loadClients();
    this.selectMap = new Map();
  },

  dispose: function() {
    $common.hideTips();
    ApracJs.UI.Print.ClientSelectorAction.callBaseMethod(this, 'dispose');
  },

  loadClients: function() {
    var that = this;
    $print.getPrintClients(function(data) {
      if (!data) data = [];
      if (data.length == 0) {
        $common.showInfo('您还没有授权远程打印机或远程打印机没有启动</br>请先获取授权码，然后进行授权');
      }
      var form = that.get_form();
      form.listClient.set_items(data);
      form.listClient.set_selectedIndex(0);
      that.doClientChanged(form.listClient);
    });
  },

  doClientChanged: function(sender) {
    var grid = this.get_form().gridPrint;
    var index = sender.get_selectedIndex();
    var items = sender.get_items();
    if (items.length === 0) {
      grid.refresh(null);
      return;
    }

    var selectClient = items[index];
    var printerNames = [];
    for (var i = 0; i < selectClient.printerNames.length; i++) {
      printerNames.push({ PrinterName: selectClient.printerNames[i].printerName });
    }
    grid.refresh(printerNames);
  },

  doSelect: function(sender) {
    var form = sender.get_form();
    var printer = form.gridPrint.get_selectedRowData();
    if (!printer) return;
    var clientToken = form.listClient.get_value();
    var clientTagName = form.listClient.get_text();
    var printerName = printer.PrinterName;
    var text = clientTagName + "(" + printerName + ")";
    var item = {
      text: text,
      clientToken: clientToken,
      printerName: printerName
    };
    this.selectMap.set(item.clientToken, item);
    this.refreshItems();
  },

  refreshItems: function() {
    var btnsSelect = this.get_form().btnsSelect;
    var items = [];
    this.selectMap.forEach(function(value) {
      items.push(value);
    });
    btnsSelect.set_items(items);
  },

  doRefresh: function(sender) {
    var grid = this.get_form().gridPrint;
    grid.dataBind([]);
    this.loadClients();
    this.selectMap.clear();
    this.refreshItems();
  },

  doGetAccessCode: function(sender) {
    $print.getAccessCode(function(result) {
      if (!result) {
        $common.showTips('授权码获取异常');
        return;
      }
      sender.get_form().teAccessCode.set_text(result.accessCode);
    });
  },

  doRemove: function(sender, args) {
    var clientToken = args.get_data().clientToken;
    this.selectMap.delete(clientToken);
    this.refreshItems();
  },

  doSure: function(sender) {
    if (this.selectMap.size === 0) {
      $common.showTips('请先双击打印机列表选择打印机');
      return;
    }
    var items = [];
    this.selectMap.forEach(function(value) {
      items.push(value);
    });
    var form = sender.get_form();
    form.result = items;
    form.doOk();
  }
};
ApracJs.UI.Print.ClientSelectorAction.registerClass('ApracJs.UI.Print.ClientSelectorAction', Sys.UI.PageAction);
